@@ -1,8 +1,6 @@
 #
 # (c) Nathan Abu <aloha2004@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -24,11 +22,12 @@ With this module you can define hostgroups out of an xml file.
 
 package Rex::Group::Lookup::XML;
 
+use 5.010001;
 use strict;
 use warnings;
 use Rex -base;
 
-our $VERSION = '1.12.2'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 require Exporter;
 use base qw(Exporter);
