@@ -1,15 +1,14 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Test::Base::has_content;
 
+use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '1.8.1'; # VERSION
+our $VERSION = '1.14.0'; # VERSION
 
 use Rex -base;
 use base qw(Rex::Test::Base);
